import React, { useMemo, useState } from 'react';
import { Col, Container, Row, Table } from 'react-bootstrap';
import { RBTMenuBar } from '../menubar';
import { RBTRowControls } from '../rowcontrols';
import { CompareRBTRow } from '../common';
import { RBTableHead } from '../tableHead';
import { RBTablePlaceholder } from '../tablePlaceholder';
import { RBTableBody } from '../tableBody/tableBody.components';
export const RBTable = ({ columns, data, enableDensityToggle, enableTableHead, name, varient, }) => {
    //
    const initialisedRows = useMemo(() => {
        const results = [];
        //
        if (data) {
            for (let index = 0; index < data.length; index++) {
                const row = {
                    data: data[index],
                    position: index,
                    filters: [],
                };
                results.push(row);
            }
        }
        // Ensure all the results are correctly sorted
        return results.sort(CompareRBTRow);
    }, [data]);
    const showTableHead = useMemo(() => enableTableHead ?? true, [enableTableHead]);
    // We want to wrap eac data item within a row object which controls how informaiton is displayed
    // by default nothing should be filtered from view and everything should be displayed.
    const [rows, setRows] = useState(initialisedRows);
    const [columnDefs] = useState(columns ?? []);
    const [compact, setCompact] = useState(false);
    const styleVarient = useMemo(() => varient ?? 'dark', [varient]);
    const tableName = useMemo(() => {
        let result = 'Table';
        if (name && name.length > 0) {
            result = name + ' Table';
        }
        return result;
    }, [name]);
    return (React.createElement(Container, { fluid: true },
        React.createElement(RBTMenuBar, { enableDensityToggle: enableDensityToggle, isCompact: compact, setCompact: setCompact, name: name, varient: styleVarient, columns: columnDefs, data: rows, handleDisplayedRows: setRows }),
        React.createElement(Row, null,
            React.createElement(Col, null,
                React.createElement(Table, { hover: true, responsive: true, size: compact ? 'sm' : '', "aria-label": tableName },
                    React.createElement(RBTableHead, { columns: columnDefs, enableTableHead: showTableHead, name: name, varient: styleVarient }),
                    rows.length > 0 ? (React.createElement(RBTableBody, { columns: columnDefs, name: name, varient: styleVarient, data: rows })) : (React.createElement(RBTablePlaceholder, { columns: columnDefs, name: name, varient: styleVarient }))))),
        React.createElement(RBTRowControls, { columns: columnDefs, data: rows, handleDisplayedRows: setRows, name: name, varient: styleVarient })));
};
//# sourceMappingURL=table.components.js.map