import React, { useMemo } from 'react';
import { CompareRBTRow } from '../common';
export const RBTableBody = ({ columns, data, name, }) => {
    const columnPrefix = useMemo(() => (name && name.length > 0 ? name + '.table.body' : 'table.body'), [name]);
    const displayed = useMemo(() => {
        const results = [];
        for (let index = 0; index < data.length; index++) {
            if (data[index].filters.length === 0) {
                results.push(data[index]);
            }
        }
        return results.sort(CompareRBTRow);
    }, [data]);
    /**
     * This will process the Cell atribute (if set)
     * @param column
     * @param row
     * @returns
     */
    const GenerateCell = (index, column, row) => {
        let id = columnPrefix;
        if (column.id && column.id.length > 0) {
            id = column.id;
        }
        let result;
        if (typeof column.Cell === 'function') {
            result = column.Cell({ column: id, originalRow: row.data });
        }
        else {
            result = column.Cell;
        }
        // If there was no Id or Cell then result should be undefined
        if (!result && column.accessorKey) {
            const data = row.data[column.accessorKey];
            if (typeof data === 'string' || typeof data === 'number') {
                result = React.createElement("td", { key: id + '.' + row.position + '.' + index }, data);
            }
            else {
                console.log('GenerateCell - Unable to convert data into table cell: ' + JSON.stringify(data));
            }
        }
        else {
            console.log('No Id or Accessor key\ncolumn: ' + JSON.stringify(column) + '\nrow: ' + JSON.stringify(data));
            result = React.createElement("td", { key: id + '.' + row.position + '.' + index });
        }
        return result;
    };
    return (React.createElement("tbody", null, displayed.map((row) => {
        return (React.createElement("tr", { key: row.position }, columns.map((column, index) => {
            return GenerateCell(index, column, row);
        })));
    })));
};
//# sourceMappingURL=tableBody.components.js.map